pub enum PruningStrategy {
Default,
Everything,
Nothing,
Custom,
}Expand description
We follow cosmos-sdk pruning strategies for convenience’s sake.
Variants
Default
‘Default’ strategy defines a pruning strategy where the last 362880 heights are kept where to-be pruned heights are pruned at every 10th height. The last 362880 heights are kept(approximately 3.5 weeks worth of state) assuming the typical block time is 6s. If these values do not match the applications’ requirements, use the “custom” option.
Everything
‘Everything’ strategy defines a pruning strategy where all committed heights are deleted, storing only the current height and last 2 states. To-be pruned heights are pruned at every 10th height.
Nothing
‘Nothing’ strategy defines a pruning strategy where all heights are kept on disk.
Custom
‘Custom’ strategy defines a pruning strategy where the user specifies the pruning.
Implementations
Sourceimpl PruningStrategy
impl PruningStrategy
pub fn is_custom(&self) -> bool
pub fn is_nothing(&self) -> bool
pub fn is_everything(&self) -> bool