Block

Struct Block 

#[non_exhaustive]
pub struct Block { pub header: Header, pub data: Vec<Vec<u8>>, pub evidence: List, pub last_commit: Option<Commit>, }
Blocks consist of a header, transactions, votes (the commit), and a list of evidence of malfeasance (i.e. signing conflicting votes).

https://github.com/cometbft/cometbft/blob/v1.0.0-alpha.1/spec/core/data_structures.md#block

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
header: Header

Block header

data: Vec<Vec<u8>>

Transaction data

evidence: List

Evidence of malfeasance

last_commit: Option<Commit>

Last commit, should be None for the initial block.

Implementations

Source

impl Block

pub fn new( header: Header, data: Vec<Vec<u8>>, evidence: List, last_commit: Option<Commit>, ) -> Block

Builds a new Block, based on the given Header, data, evidence, and last commit.

pub fn header(&self) -> &Header

Get header

pub fn data(&self) -> &Vec<Vec<u8>>

Get data

pub fn evidence(&self) -> &List

Get evidence

pub fn last_commit(&self) -> &Option<Commit>

Get last commit