Config

Struct Config 

pub struct Config {
    pub websocket_url: Url,
    pub rpc_url: Url,
    pub database_storage: String,
    pub pruning_options: PruningOptions,
    pub store_precommits: bool,
    pub start_block: StartingBlockOpts,
}

Fields

websocket_url: Url

Url to the websocket endpoint of a validator, for example wss://rpc.nymtech.net/websocket

rpc_url: Url

Url to the rpc endpoint of a validator, for example https://rpc.nymtech.net/

database_storage: String

Points to either underlying file (sqlite) or connection string (postgres)

pruning_options: PruningOptionsstore_precommits: boolstart_block: StartingBlockOpts