pub struct PruningOptions {
pub keep_recent: u32,
pub interval: u32,
pub strategy: PruningStrategy,
}Fields
keep_recent: u32keep_recent defines how many recent heights to keep on disk.
interval: u32interval defines the frequency of removing the pruned heights from the disk.
strategy: PruningStrategystrategy defines the currently used kind of PruningStrategy.
Implementations
Sourceimpl PruningOptions
impl PruningOptions
pub fn validate(&self) -> Result<(), ScraperError>
pub fn nothing() -> Self
pub fn strategy_interval(&self) -> u32
pub fn strategy_keep_recent(&self) -> u32