StartingBlockOpts

Struct StartingBlockOpts 

pub struct StartingBlockOpts {
    pub start_block_height: Option<u32>,
    pub use_best_effort_start_height: bool,
}

Fields

start_block_height: Option<u32>use_best_effort_start_height: bool

If the scraper fails to start from the desired height, rather than failing, attempt to use the next available height