Re-exports
pub use crate::ParsedTransactionResponse;
Modules
- helpers
- validators
/validatorsendpoint JSON-RPC wrapper
Structs
- Block
- Blocks consist of a header, transactions, votes (the commit), and a list of evidence of malfeasance (i.e. signing conflicting votes).
- Commit
- Commit contains the justification (ie. a set of signatures) that a block was committed by a set of validators. TODO: Update links below! https://github.com/tendermint/tendermint/blob/51dc810d041eaac78320adc6d53ad8b160b06601/types/block.go#L486-L502 https://github.com/tendermint/spec/blob/d46cd7f573a2c6a2399fcab2cde981330aa63f37/spec/core/data_structures.md#lastcommit
- Full
Block Information - Nyxd
Scraper Storage Error
Enums
- Commit
Sig - CommitSig represents a signature of a validator. It’s a part of the Commit and can be used to reconstruct the vote set given the validator set.